import TestimonialClient from "@/components/shared/testimonial-client";
import { Locale } from "@/i18n/routing";
import { fetchProjects } from "@/servers/actions/project-action";
import { getTestimonialData } from "@/utils/get-fake-data";
import { dehydrate, HydrationBoundary, QueryClient } from "@tanstack/react-query";

interface TestimonialProps {
  locale: Locale;
}

export default async function Testimonial({ locale }: TestimonialProps) {
  const data = await getTestimonialData();

  const queryClient = new QueryClient();
  await queryClient.prefetchQuery({
    queryKey: ["projects"],
    queryFn: () => fetchProjects(),
  });

  return  <HydrationBoundary state={dehydrate(queryClient)}>
            <TestimonialClient data={data} locale={locale} />
          </HydrationBoundary>;
}
